@@ -3,6 +3,6 @@ from django.apps import AppConfig as DjangoAppConfig
 
 class AppConfig(DjangoAppConfig):
     name = "edc_protocol_violation"
-    verbose_name = "Edc Protocol Deviations/Violations"
+    verbose_name = "Edc Protocol Incidents"
     has_exportable_data = True
     include_in_administration_section = True
